#-*- coding: utf-8 -*-

# pyPastebin is a simple application that helps you
# to send simply a command output or a file content 
# to paste it on a pastebin service
#Copyright (C) <2008>  <Marco Buccini>
#This program is free software: you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation, either version 3 of the License, or
#(at your option) any later version.

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program.  If not, see <http://www.gnu.org/licenses/>.


import os
import sys
from subprocess import Popen, PIPE, STDOUT


version = sys.platform

class PopenObj(object):
    
    """
    This is the PyPaste object. 
    It defines some methods for the creation of a Popen object.
    
    @cmd      = command
    @infile   = /path/to/file
    @verbose  = True|False(default)
    """
    
    def __init__(self, cmd, infile, verbose=False):
        if not cmd and not infile:
            raise OSError('You must to choose a command or '\
                                     'a file to paste on a paste service')
        
        if cmd:
            self.command = cmd
            try:
                if version == "linux2":
                    close_fds = True
                else:
                    close_fds = False
                self.pipe = Popen(self.command, bufsize=1, stdin=PIPE,
                                  stdout=PIPE, stderr=STDOUT, shell= True,
                                  close_fds=close_fds)

            except ValueError, e:
                print "Error. Invalid arguments: %s" % e
                sys.exit()
        else:
            self.command = ""
        
        if infile:
            self._infile = infile
        else:
            self._infile = ""
        
        self._verbose = verbose

    def is_verbose(self):
        return self._verbose
        
    def show_output(self):
        # we return the output, according to the options
        # selected: command/file or command & file
        
        if self.command and self._infile:
            try:
                return str(u"'%s' output:\n%s\nFile '%s':\n%s\n"
                        % ( self.command, self.pipe.stdout.read(), self._infile,
                            self.read_infile()
                            )
                        )
            except OSError, e:
                print("Couldn't read the file: %s" % e)
                sys.exit(1)
                
        elif self.command:
            return self.pipe.stdout.read()
        
        elif self._infile:
            try:
                return self.read_infile()
            except OSError, e:
                print("Couldn't read the file: %s" % e)
                sys.exit(1)
            
    def read_infile(self):
        # we read the file and output its content 
        if self._infile:
            if os.path.exists(self._infile):
                    infile = open(self._infile,'r').read()
                    return infile
            else:
                raise OSError("File does not exist.")
            
    def __str__(self):
        return u"%s" %self.show_output()
                
